==> jc-1.4.0.tar.gz: gnu/java/awt/EventModifier.h <==
// public class gnu.java.awt.EventModifier

// class file dependencies
// @dep_class 5e37ea21aae6e49e gnu_java_awt_EventModifier
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_awt_EventModifier_H_
#define _JC_gnu_java_awt_EventModifier_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_EventModifier$sub_refs	_jc_gnu_java_awt_EventModifier$sub_refs;
typedef struct _jc_gnu_java_awt_EventModifier$sub_nonrefs	_jc_gnu_java_awt_EventModifier$sub_nonrefs;
typedef struct _jc_gnu_java_awt_EventModifier$refs	_jc_gnu_java_awt_EventModifier$refs;
typedef struct _jc_gnu_java_awt_EventModifier$nonrefs	_jc_gnu_java_awt_EventModifier$nonrefs;
typedef struct _jc_gnu_java_awt_EventModifier$object	_jc_gnu_java_awt_EventModifier$object;

typedef struct _jc_gnu_java_awt_EventModifier$fields_struct	_jc_gnu_java_awt_EventModifier$fields_struct;
typedef const struct _jc_gnu_java_awt_EventModifier$vmethods	_jc_gnu_java_awt_EventModifier$vmethods;
typedef const struct _jc_gnu_java_awt_EventModifier$vtable	_jc_gnu_java_awt_EventModifier$vtable;
typedef const struct _jc_gnu_java_awt_EventModifier$vtype	_jc_gnu_java_awt_EventModifier$vtype;

// Class fields structure
struct _jc_gnu_java_awt_EventModifier$fields_struct {
	jint	NEW__5fMASK;
	jint	OLD__5fMASK;
};
extern _jc_gnu_java_awt_EventModifier$fields_struct _jc_gnu_java_awt_EventModifier$class_fields;

// Constructors
extern void _jc_gnu_java_awt_EventModifier$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_awt_EventModifier$object *);

// Static methods
extern jint _jc_gnu_java_awt_EventModifier$method$extend$d249fbed86469f9d(_jc_env *, jint);
extern jint _jc_gnu_java_awt_EventModifier$method$revert$c538f98fb8237a4a(_jc_env *, jint);

// Virtual methods structure
struct _jc_gnu_java_awt_EventModifier$vmethods {
};

// Vtable
struct _jc_gnu_java_awt_EventModifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_EventModifier$vmethods	gnu_java_awt_EventModifier;
};

// Vtype
struct _jc_gnu_java_awt_EventModifier$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_EventModifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_EventModifier$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_EventModifier$refs {
    _jc_gnu_java_awt_EventModifier$sub_refs	gnu_java_awt_EventModifier;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_EventModifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_EventModifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_EventModifier$sub_nonrefs	gnu_java_awt_EventModifier;
};

// Object instance structure
struct _jc_gnu_java_awt_EventModifier$object {
	_jc_gnu_java_awt_EventModifier$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_EventModifier$vtype	*vtype;
	_jc_gnu_java_awt_EventModifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_EventModifier$vtype _jc_gnu_java_awt_EventModifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_EventModifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_EventModifier$class_object;

#endif	/* _JC_gnu_java_awt_EventModifier_H_ */

==> jc-1.4.6.tar.gz: gnu/java/awt/EventModifier.h <==
// public class gnu.java.awt.EventModifier

// class file dependencies
// @dep_class 5e37ea21aae6e49e gnu_java_awt_EventModifier
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_awt_EventModifier_H_
#define _JC_gnu_java_awt_EventModifier_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_EventModifier$sub_refs	_jc_gnu_java_awt_EventModifier$sub_refs;
typedef struct _jc_gnu_java_awt_EventModifier$sub_nonrefs	_jc_gnu_java_awt_EventModifier$sub_nonrefs;
typedef struct _jc_gnu_java_awt_EventModifier$refs	_jc_gnu_java_awt_EventModifier$refs;
typedef struct _jc_gnu_java_awt_EventModifier$nonrefs	_jc_gnu_java_awt_EventModifier$nonrefs;
typedef struct _jc_gnu_java_awt_EventModifier$object	_jc_gnu_java_awt_EventModifier$object;

typedef struct _jc_gnu_java_awt_EventModifier$fields_struct	_jc_gnu_java_awt_EventModifier$fields_struct;
typedef const struct _jc_gnu_java_awt_EventModifier$vmethods	_jc_gnu_java_awt_EventModifier$vmethods;
typedef const struct _jc_gnu_java_awt_EventModifier$vtable	_jc_gnu_java_awt_EventModifier$vtable;
typedef const struct _jc_gnu_java_awt_EventModifier$vtype	_jc_gnu_java_awt_EventModifier$vtype;

// Class fields structure
struct _jc_gnu_java_awt_EventModifier$fields_struct {
	jint	NEW__5fMASK;
	jint	OLD__5fMASK;
};
extern _jc_gnu_java_awt_EventModifier$fields_struct _jc_gnu_java_awt_EventModifier$class_fields;

// Constructors
extern void _jc_gnu_java_awt_EventModifier$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_awt_EventModifier$object *) _JC_JCNI_ATTR;

// Static methods
extern jint _jc_gnu_java_awt_EventModifier$method$extend$d249fbed86469f9d(_jc_env *, jint) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_awt_EventModifier$method$revert$c538f98fb8237a4a(_jc_env *, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_awt_EventModifier$vmethods {
};

// Vtable
struct _jc_gnu_java_awt_EventModifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_EventModifier$vmethods	gnu_java_awt_EventModifier;
};

// Vtype
struct _jc_gnu_java_awt_EventModifier$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_EventModifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_EventModifier$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_EventModifier$refs {
    _jc_gnu_java_awt_EventModifier$sub_refs	gnu_java_awt_EventModifier;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_EventModifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_EventModifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_EventModifier$sub_nonrefs	gnu_java_awt_EventModifier;
};

// Object instance structure
struct _jc_gnu_java_awt_EventModifier$object {
	_jc_gnu_java_awt_EventModifier$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_EventModifier$vtype	*vtype;
	_jc_gnu_java_awt_EventModifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_EventModifier$vtype _jc_gnu_java_awt_EventModifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_EventModifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_EventModifier$class_object;

#endif	/* _JC_gnu_java_awt_EventModifier_H_ */
